configure method
Provision the client. This method must be called before any subsequent methods.
It's recommended that this method is awaitd in void main() before runApp.
projectPackageName should reflect the name of the package where bugsnag_flutter
is imported.
Implementation
Future<void> configure({
String? androidApiKey,
String? iosApiKey,
bool persistUser = true,
String? releaseStage,
String? projectPackageName,
}) {
instance.projectPackageName = projectPackageName;
return _channel.invokeMethod('configure', {
'androidApiKey': androidApiKey,
'iosApiKey': iosApiKey,
'persistUser': persistUser.toString(),
'releaseStage': releaseStage,
});
}